@@ -385,10 +385,11 @@ static int handle_packet(void)
     } else {
       int status;
 
+      /* Leave SIGCHLD blocked so the waitpid() below works correctly  */
+      sigaddset(&oldsig, SIGCHLD);
       sigprocmask(SIG_SETMASK, &oldsig, NULL);
       mt->pid = f;
       mt->wait_queue_token = pkt.wait_queue_token;
-      sigprocmask(SIG_BLOCK, &chldsig, NULL);
       mt->next = ap.mounts;
       ap.mounts = mt;
       if ( waitpid(f, &status, WUNTRACED) != f ||
